# -*- mode: Conf; -*-
SUMMARY = "Amazon Kinesis Video Streams CPP Producer"
DESCRIPTION = "Amazon Kinesis Video Streams Producer SDK for C/C++ makes it easy to build an on-device application that securely connects to a video stream, and reliably publishes video and other media data to Kinesis Video Streams. It takes care of all the underlying tasks required to package the frames and fragments generated by the device's media pipeline. The SDK also handles stream creation, token rotation for secure and uninterrupted streaming, processing acknowledgements returned by Kinesis Video Streams, and other tasks."
HOMEPAGE = "https://github.com/awslabs/amazon-kinesis-video-streams-producer-sdk-cpp"
LICENSE = "Apache-2.0"
PROVIDES += "aws/amazon-kvs-producer-sdk-cpp"

inherit cmake
inherit pkgconfig

BRANCH ?= "master"
SDIR ?= "amazon-kvs-producer-sdk-cpp"

LIC_FILES_CHKSUM = "file://${SDIR}/LICENSE;md5=34400b68072d710fecd0a2940a0d1658"

SRC_URI = "git://github.com/awslabs/amazon-kinesis-video-streams-producer-sdk-cpp.git;protocol=https;branch=${BRANCH};destsuffix=${S}/${SDIR} \
           file://amazon-kvs-producer-sdk-cpp-deps.patch"
SRCREV = "00ba9cfc3f1835adad1a626f2c86ec082b8bfbac"

S = "${WORKDIR}/git"

DEPENDS = "openssl amazon-kvs-producer-sdk-c gtest jsmn log4cplus"
RDEPENDS:${PN} = ""
CFLAGS:append = " -Wl,-Bsymbolic"
OECMAKE_BUILDPATH += "${WORKDIR}/build"
OECMAKE_SOURCEPATH += "${S}/${SDIR}"

EXTRA_OECMAKE += "-DBUILD_DEPENDENCIES=OFF"
EXTRA_OECMAKE += "-DBUILD_GSTREAMER_PLUGIN=OFF"
EXTRA_OECMAKE += "-DBUILD_JNI=OFF"
EXTRA_OECMAKE += "-DBUILD_STATIC=OFF"
EXTRA_OECMAKE += "-DBUILD_DEPENDENCIES=OFF"
EXTRA_OECMAKE += "-DBUILD_OPENSSL_PLATFORM=OFF"
EXTRA_OECMAKE += "-DCODE_COVERAGE=OFF"
EXTRA_OECMAKE += "-DCOMPILER_WARNINGS=OFF"
EXTRA_OECMAKE += "-DADDRESS_SANITIZER=OFF"
EXTRA_OECMAKE += "-DMEMORY_SANITIZER=OFF"
EXTRA_OECMAKE += "-DTHREAD_SANITIZER=OFF"
EXTRA_OECMAKE += "-DUNDEFINED_BEHAVIOR_SANITIZER=OFF"
EXTRA_OECMAKE += "-DBUILD_TEST=OFF"
EXTRA_OECMAKE += "-DBUILD_SHARED_LIBS=ON"
EXTRA_OECMAKE += "-DCMAKE_BUILD_TYPE=Release"
EXTRA_OECMAKE += "-DCMAKE_INSTALL_PREFIX=$D/usr"


do_install() {
    install -d ${D}/usr/lib
    install -d ${D}/usr/include/com
    install -d ${D}/usr/include/com/amazonaws
    install -d ${D}/usr/include/com/amazonaws/kinesis
    install -d ${D}/usr/include/com/amazonaws/kinesis/video
    install -d ${D}/usr/include/com/amazonaws/kinesis/video/producer
    install -d ${D}/usr/include/com/amazonaws/kinesis/video/producer/jni
    install -d ${D}/usr/include/com/amazonaws/kinesis/video/producer/credential-providers
    install -d ${D}/usr/include/com/amazonaws/kinesis/video/producer/gstreamer

    install -m 0640 ${WORKDIR}/git/amazon-kvs-producer-sdk-cpp/src/CachingEndpointOnlyCallbackProvider.h ${D}/usr/include/com/amazonaws/kinesis/video/producer/CachingEndpointOnlyCallbackProvider.h
    install -m 0640 ${WORKDIR}/git/amazon-kvs-producer-sdk-cpp/src/ThreadSafeMap.h ${D}/usr/include/com/amazonaws/kinesis/video/producer/ThreadSafeMap.h
    install -m 0640 ${WORKDIR}/git/amazon-kvs-producer-sdk-cpp/src/DefaultCallbackProvider.h ${D}/usr/include/com/amazonaws/kinesis/video/producer/DefaultCallbackProvider.h
    install -m 0640 ${WORKDIR}/git/amazon-kvs-producer-sdk-cpp/src/StreamCallbackProvider.h ${D}/usr/include/com/amazonaws/kinesis/video/producer/StreamCallbackProvider.h
    install -m 0640 ${WORKDIR}/git/amazon-kvs-producer-sdk-cpp/src/KinesisVideoProducer.h ${D}/usr/include/com/amazonaws/kinesis/video/producer/KinesisVideoProducer.h
    install -m 0640 ${WORKDIR}/git/amazon-kvs-producer-sdk-cpp/src/DefaultDeviceInfoProvider.h ${D}/usr/include/com/amazonaws/kinesis/video/producer/DefaultDeviceInfoProvider.h
    install -m 0640 ${WORKDIR}/git/amazon-kvs-producer-sdk-cpp/src/CallbackProvider.h ${D}/usr/include/com/amazonaws/kinesis/video/producer/CallbackProvider.h
    install -m 0640 ${WORKDIR}/git/amazon-kvs-producer-sdk-cpp/src/StreamTags.h ${D}/usr/include/com/amazonaws/kinesis/video/producer/StreamTags.h
    install -m 0640 ${WORKDIR}/git/amazon-kvs-producer-sdk-cpp/src/Logger.h ${D}/usr/include/com/amazonaws/kinesis/video/producer/Logger.h
    install -m 0640 ${WORKDIR}/git/amazon-kvs-producer-sdk-cpp/src/KinesisVideoStream.h ${D}/usr/include/com/amazonaws/kinesis/video/producer/KinesisVideoStream.h
    install -m 0640 ${WORKDIR}/git/amazon-kvs-producer-sdk-cpp/src/ClientCallbackProvider.h ${D}/usr/include/com/amazonaws/kinesis/video/producer/ClientCallbackProvider.h

    install -m 0640 ${WORKDIR}/git/amazon-kvs-producer-sdk-cpp/src/JNI/include/com/amazonaws/kinesis/video/producer/jni/KinesisVideoClientWrapper.h ${D}/usr/include/com/amazonaws/kinesis/video/producer/jni/KinesisVideoClientWrapper.h
    install -m 0640 ${WORKDIR}/git/amazon-kvs-producer-sdk-cpp/src/JNI/include/com/amazonaws/kinesis/video/producer/jni/SyncMutex.h ${D}/usr/include/com/amazonaws/kinesis/video/producer/jni/SyncMutex.h
    install -m 0640 ${WORKDIR}/git/amazon-kvs-producer-sdk-cpp/src/JNI/include/com/amazonaws/kinesis/video/producer/jni/JNICommon.h ${D}/usr/include/com/amazonaws/kinesis/video/producer/jni/JNICommon.h
    install -m 0640 ${WORKDIR}/git/amazon-kvs-producer-sdk-cpp/src/JNI/include/com/amazonaws/kinesis/video/producer/jni/Parameters.h ${D}/usr/include/com/amazonaws/kinesis/video/producer/jni/Parameters.h
    install -m 0640 ${WORKDIR}/git/amazon-kvs-producer-sdk-cpp/src/JNI/include/com/amazonaws/kinesis/video/producer/jni/com_amazonaws_kinesisvideo_internal_producer_jni_NativeKinesisVideoProducerJni.h ${D}/usr/include/com/amazonaws/kinesis/video/producer/jni/com_amazonaws_kinesisvideo_internal_producer_jni_NativeKinesisVideoProducerJni.h
    install -m 0640 ${WORKDIR}/git/amazon-kvs-producer-sdk-cpp/src/JNI/include/com/amazonaws/kinesis/video/producer/jni/TimedSemaphore.h ${D}/usr/include/com/amazonaws/kinesis/video/producer/jni/TimedSemaphore.h

    install -m 0640 ${WORKDIR}/git/amazon-kvs-producer-sdk-cpp/src/credential-providers/RotatingCredentialProvider.h ${D}/usr/include/com/amazonaws/kinesis/video/producer/credential-providers/RotatingCredentialProvider.h
    install -m 0640 ${WORKDIR}/git/amazon-kvs-producer-sdk-cpp/src/credential-providers/IotCertCredentialProvider.h ${D}/usr/include/com/amazonaws/kinesis/video/producer/credential-providers/IotCertCredentialProvider.h

    install -m 0640 ${WORKDIR}/git/amazon-kvs-producer-sdk-cpp/src/gstreamer/KvsSinkStreamCallbackProvider.h ${D}/usr/include/com/amazonaws/kinesis/video/producer/KvsSinkStreamCallbackProvider.h
    install -m 0640 ${WORKDIR}/git/amazon-kvs-producer-sdk-cpp/src/gstreamer/KvsSinkDeviceInfoProvider.h ${D}/usr/include/com/amazonaws/kinesis/video/producer/credential-providers/KvsSinkDeviceInfoProvider.h
    install -m 0640 ${WORKDIR}/git/amazon-kvs-producer-sdk-cpp/src/gstreamer/gstkvssink.h ${D}/usr/include/com/amazonaws/kinesis/video/producer/credential-providers/gstkvssink.h

    install -m 0755 ${B}/libKinesisVideoProducer.so ${D}/usr/lib
}

FILES:${PN}     = "${libdir}/libKinesisVideoProducer.so"
FILES:${PN}-dev = "${includedir}/com/amazonaws/kinesis/video/*"
FILES:${PN}-dbg = ""

# Notify that libraries are not versioned
FILES_SOLIBSDEV = ""

BBCLASSEXTEND = "native nativesdk"
